pub struct IRBlock {
pub code: String,
}Expand description
A code block — stored as a string of Rust code for now. The codegen will emit this verbatim into the generated function.
Fields
code: StringImplementations