Token

Enum Token 

pub enum Token {
Show 73 variants Program, Ss, State, When, Entry, Exit, Option_, Assign, To, Monitor, Sync, EvFlag, If, Else, While, For, Break, Return, Int, Short, Long, Float, Double, String_, Char, Unsigned, IntLit(i64), FloatLit(f64), StringLit(String), Ident(String), LParen, RParen, LBrace, RBrace, LBracket, RBracket, Semi, Comma, Dot, Arrow, Plus, Minus, Star, Slash, Percent, Eq, Ne, Lt, Le, Gt, Ge, And, Or, Not, BitAnd, BitOr, BitXor, BitNot, Shl, Shr, Assign_, PlusEq, MinusEq, StarEq, SlashEq, PlusPlus, MinusMinus, Question, Colon, Hash, DoublePercent, EmbeddedLine(String), Eof,
}

Variants



Program



Ss



State



When



Entry



Exit



Option_



Assign



To



Monitor



Sync



EvFlag



If



Else



While



For



Break



Return



Int



Short



Long



Float



Double



String_



Char



Unsigned



IntLit(i64)



FloatLit(f64)



StringLit(String)



Ident(String)



LParen



RParen



LBrace



RBrace



LBracket



RBracket



Semi



Comma



Dot



Arrow



Plus



Minus



Star



Slash



Percent



Eq



Ne



Lt



Le



Gt



Ge



And



Or



Not



BitAnd



BitOr



BitXor



BitNot



Shl



Shr



Assign_



PlusEq



MinusEq



StarEq



SlashEq



PlusPlus



MinusMinus



Question



Colon



Hash



DoublePercent



EmbeddedLine(String)



Eof